==> aspose_barcode_cloud-0.23.6.tar.gz: lib/model/han_xin_version.dart <==
part of aspose_barcode_cloud.api;

class HanXinVersion {
  HanXinVersion._internal(this.value);

  HanXinVersion.fromJson(dynamic data) {
    switch (data) {
      case "Auto":
        value = data;
        break;
      case "Version01":
        value = data;
        break;
      case "Version02":
        value = data;
        break;
      case "Version03":
        value = data;
        break;
      case "Version04":
        value = data;
        break;
      case "Version05":
        value = data;
        break;
      case "Version06":
        value = data;
        break;
      case "Version07":
        value = data;
        break;
      case "Version08":
        value = data;
        break;
      case "Version09":
        value = data;
        break;
      case "Version10":
        value = data;
        break;
      case "Version11":
        value = data;
        break;
      case "Version12":
        value = data;
        break;
      case "Version13":
        value = data;
        break;
      case "Version14":
        value = data;
        break;
      case "Version15":
        value = data;
        break;
      case "Version16":
        value = data;
        break;
      case "Version17":
        value = data;
        break;
      case "Version18":
        value = data;
        break;
      case "Version19":
        value = data;
        break;
      case "Version20":
        value = data;
        break;
      case "Version21":
        value = data;
        break;
      case "Version22":
        value = data;
        break;
      case "Version23":
        value = data;
        break;
      case "Version24":
        value = data;
        break;
      case "Version25":
        value = data;
        break;
      case "Version26":
        value = data;
        break;
      case "Version27":
        value = data;
        break;
      case "Version28":
        value = data;
        break;
      case "Version29":
        value = data;
        break;
      case "Version30":
        value = data;
        break;
      case "Version31":
        value = data;
        break;
      case "Version32":
        value = data;
        break;
      case "Version33":
        value = data;
        break;
      case "Version34":
        value = data;
        break;
      case "Version35":
        value = data;
        break;
      case "Version36":
        value = data;
        break;
      case "Version37":
        value = data;
        break;
      case "Version38":
        value = data;
        break;
      case "Version39":
        value = data;
        break;
      case "Version40":
        value = data;
        break;
      case "Version41":
        value = data;
        break;
      case "Version42":
        value = data;
        break;
      case "Version43":
        value = data;
        break;
      case "Version44":
        value = data;
        break;
      case "Version45":
        value = data;
        break;
      case "Version46":
        value = data;
        break;
      case "Version47":
        value = data;
        break;
      case "Version48":
        value = data;
        break;
      case "Version49":
        value = data;
        break;
      case "Version50":
        value = data;
        break;
      case "Version51":
        value = data;
        break;
      case "Version52":
        value = data;
        break;
      case "Version53":
        value = data;
        break;
      case "Version54":
        value = data;
        break;
      case "Version55":
        value = data;
        break;
      case "Version56":
        value = data;
        break;
      case "Version57":
        value = data;
        break;
      case "Version58":
        value = data;
        break;
      case "Version59":
        value = data;
        break;
      case "Version60":
        value = data;
        break;
      case "Version61":
        value = data;
        break;
      case "Version62":
        value = data;
        break;
      case "Version63":
        value = data;
        break;
      case "Version64":
        value = data;
        break;
      case "Version65":
        value = data;
        break;
      case "Version66":
        value = data;
        break;
      case "Version67":
        value = data;
        break;
      case "Version68":
        value = data;
        break;
      case "Version69":
        value = data;
        break;
      case "Version70":
        value = data;
        break;
      case "Version71":
        value = data;
        break;
      case "Version72":
        value = data;
        break;
      case "Version73":
        value = data;
        break;
      case "Version74":
        value = data;
        break;
      case "Version75":
        value = data;
        break;
      case "Version76":
        value = data;
        break;
      case "Version77":
        value = data;
        break;
      case "Version78":
        value = data;
        break;
      case "Version79":
        value = data;
        break;
      case "Version80":
        value = data;
        break;
      case "Version81":
        value = data;
        break;
      case "Version82":
        value = data;
        break;
      case "Version83":
        value = data;
        break;
      case "Version84":
        value = data;
        break;
      default:
        throw Exception('Unknown enum value to decode: $data');
    }
  }

  /// The underlying value of this enum member.
  String? value;

  ///
  static HanXinVersion auto_ = HanXinVersion._internal("Auto");

  ///
  static HanXinVersion version01_ = HanXinVersion._internal("Version01");

  ///
  static HanXinVersion version02_ = HanXinVersion._internal("Version02");

  ///
  static HanXinVersion version03_ = HanXinVersion._internal("Version03");

  ///
  static HanXinVersion version04_ = HanXinVersion._internal("Version04");

  ///
  static HanXinVersion version05_ = HanXinVersion._internal("Version05");

  ///
  static HanXinVersion version06_ = HanXinVersion._internal("Version06");

  ///
  static HanXinVersion version07_ = HanXinVersion._internal("Version07");

  ///
  static HanXinVersion version08_ = HanXinVersion._internal("Version08");

  ///
  static HanXinVersion version09_ = HanXinVersion._internal("Version09");

  ///
  static HanXinVersion version10_ = HanXinVersion._internal("Version10");

  ///
  static HanXinVersion version11_ = HanXinVersion._internal("Version11");

  ///
  static HanXinVersion version12_ = HanXinVersion._internal("Version12");

  ///
  static HanXinVersion version13_ = HanXinVersion._internal("Version13");

  ///
  static HanXinVersion version14_ = HanXinVersion._internal("Version14");

  ///
  static HanXinVersion version15_ = HanXinVersion._internal("Version15");

  ///
  static HanXinVersion version16_ = HanXinVersion._internal("Version16");

  ///
  static HanXinVersion version17_ = HanXinVersion._internal("Version17");

  ///
  static HanXinVersion version18_ = HanXinVersion._internal("Version18");

  ///
  static HanXinVersion version19_ = HanXinVersion._internal("Version19");

  ///
  static HanXinVersion version20_ = HanXinVersion._internal("Version20");

  ///
  static HanXinVersion version21_ = HanXinVersion._internal("Version21");

  ///
  static HanXinVersion version22_ = HanXinVersion._internal("Version22");

  ///
  static HanXinVersion version23_ = HanXinVersion._internal("Version23");

  ///
  static HanXinVersion version24_ = HanXinVersion._internal("Version24");

  ///
  static HanXinVersion version25_ = HanXinVersion._internal("Version25");

  ///
  static HanXinVersion version26_ = HanXinVersion._internal("Version26");

  ///
  static HanXinVersion version27_ = HanXinVersion._internal("Version27");

  ///
  static HanXinVersion version28_ = HanXinVersion._internal("Version28");

  ///
  static HanXinVersion version29_ = HanXinVersion._internal("Version29");

  ///
  static HanXinVersion version30_ = HanXinVersion._internal("Version30");

  ///
  static HanXinVersion version31_ = HanXinVersion._internal("Version31");

  ///
  static HanXinVersion version32_ = HanXinVersion._internal("Version32");

  ///
  static HanXinVersion version33_ = HanXinVersion._internal("Version33");

  ///
  static HanXinVersion version34_ = HanXinVersion._internal("Version34");

  ///
  static HanXinVersion version35_ = HanXinVersion._internal("Version35");

  ///
  static HanXinVersion version36_ = HanXinVersion._internal("Version36");

  ///
  static HanXinVersion version37_ = HanXinVersion._internal("Version37");

  ///
  static HanXinVersion version38_ = HanXinVersion._internal("Version38");

  ///
  static HanXinVersion version39_ = HanXinVersion._internal("Version39");

  ///
  static HanXinVersion version40_ = HanXinVersion._internal("Version40");

  ///
  static HanXinVersion version41_ = HanXinVersion._internal("Version41");

  ///
  static HanXinVersion version42_ = HanXinVersion._internal("Version42");

  ///
  static HanXinVersion version43_ = HanXinVersion._internal("Version43");

  ///
  static HanXinVersion version44_ = HanXinVersion._internal("Version44");

  ///
  static HanXinVersion version45_ = HanXinVersion._internal("Version45");

  ///
  static HanXinVersion version46_ = HanXinVersion._internal("Version46");

  ///
  static HanXinVersion version47_ = HanXinVersion._internal("Version47");

  ///
  static HanXinVersion version48_ = HanXinVersion._internal("Version48");

  ///
  static HanXinVersion version49_ = HanXinVersion._internal("Version49");

  ///
  static HanXinVersion version50_ = HanXinVersion._internal("Version50");

  ///
  static HanXinVersion version51_ = HanXinVersion._internal("Version51");

  ///
  static HanXinVersion version52_ = HanXinVersion._internal("Version52");

  ///
  static HanXinVersion version53_ = HanXinVersion._internal("Version53");

  ///
  static HanXinVersion version54_ = HanXinVersion._internal("Version54");

  ///
  static HanXinVersion version55_ = HanXinVersion._internal("Version55");

  ///
  static HanXinVersion version56_ = HanXinVersion._internal("Version56");

  ///
  static HanXinVersion version57_ = HanXinVersion._internal("Version57");

  ///
  static HanXinVersion version58_ = HanXinVersion._internal("Version58");

  ///
  static HanXinVersion version59_ = HanXinVersion._internal("Version59");

  ///
  static HanXinVersion version60_ = HanXinVersion._internal("Version60");

  ///
  static HanXinVersion version61_ = HanXinVersion._internal("Version61");

  ///
  static HanXinVersion version62_ = HanXinVersion._internal("Version62");

  ///
  static HanXinVersion version63_ = HanXinVersion._internal("Version63");

  ///
  static HanXinVersion version64_ = HanXinVersion._internal("Version64");

  ///
  static HanXinVersion version65_ = HanXinVersion._internal("Version65");

  ///
  static HanXinVersion version66_ = HanXinVersion._internal("Version66");

  ///
  static HanXinVersion version67_ = HanXinVersion._internal("Version67");

  ///
  static HanXinVersion version68_ = HanXinVersion._internal("Version68");

  ///
  static HanXinVersion version69_ = HanXinVersion._internal("Version69");

  ///
  static HanXinVersion version70_ = HanXinVersion._internal("Version70");

  ///
  static HanXinVersion version71_ = HanXinVersion._internal("Version71");

  ///
  static HanXinVersion version72_ = HanXinVersion._internal("Version72");

  ///
  static HanXinVersion version73_ = HanXinVersion._internal("Version73");

  ///
  static HanXinVersion version74_ = HanXinVersion._internal("Version74");

  ///
  static HanXinVersion version75_ = HanXinVersion._internal("Version75");

  ///
  static HanXinVersion version76_ = HanXinVersion._internal("Version76");

  ///
  static HanXinVersion version77_ = HanXinVersion._internal("Version77");

  ///
  static HanXinVersion version78_ = HanXinVersion._internal("Version78");

  ///
  static HanXinVersion version79_ = HanXinVersion._internal("Version79");

  ///
  static HanXinVersion version80_ = HanXinVersion._internal("Version80");

  ///
  static HanXinVersion version81_ = HanXinVersion._internal("Version81");

  ///
  static HanXinVersion version82_ = HanXinVersion._internal("Version82");

  ///
  static HanXinVersion version83_ = HanXinVersion._internal("Version83");

  ///
  static HanXinVersion version84_ = HanXinVersion._internal("Version84");

  static dynamic encode(HanXinVersion data) => data.value;

  String? toJson() => value;

  @override
  String toString() => value == null ? "null" : value.toString();
}

==> aspose_barcode_cloud-0.23.7.tar.gz: lib/model/han_xin_version.dart <==
part of aspose_barcode_cloud.api;

class HanXinVersion {
  /// The underlying value of this enum member.
  String? value;

  HanXinVersion._internal(this.value);

  ///
  static HanXinVersion auto_ = HanXinVersion._internal("Auto");

  ///
  static HanXinVersion version01_ = HanXinVersion._internal("Version01");

  ///
  static HanXinVersion version02_ = HanXinVersion._internal("Version02");

  ///
  static HanXinVersion version03_ = HanXinVersion._internal("Version03");

  ///
  static HanXinVersion version04_ = HanXinVersion._internal("Version04");

  ///
  static HanXinVersion version05_ = HanXinVersion._internal("Version05");

  ///
  static HanXinVersion version06_ = HanXinVersion._internal("Version06");

  ///
  static HanXinVersion version07_ = HanXinVersion._internal("Version07");

  ///
  static HanXinVersion version08_ = HanXinVersion._internal("Version08");

  ///
  static HanXinVersion version09_ = HanXinVersion._internal("Version09");

  ///
  static HanXinVersion version10_ = HanXinVersion._internal("Version10");

  ///
  static HanXinVersion version11_ = HanXinVersion._internal("Version11");

  ///
  static HanXinVersion version12_ = HanXinVersion._internal("Version12");

  ///
  static HanXinVersion version13_ = HanXinVersion._internal("Version13");

  ///
  static HanXinVersion version14_ = HanXinVersion._internal("Version14");

  ///
  static HanXinVersion version15_ = HanXinVersion._internal("Version15");

  ///
  static HanXinVersion version16_ = HanXinVersion._internal("Version16");

  ///
  static HanXinVersion version17_ = HanXinVersion._internal("Version17");

  ///
  static HanXinVersion version18_ = HanXinVersion._internal("Version18");

  ///
  static HanXinVersion version19_ = HanXinVersion._internal("Version19");

  ///
  static HanXinVersion version20_ = HanXinVersion._internal("Version20");

  ///
  static HanXinVersion version21_ = HanXinVersion._internal("Version21");

  ///
  static HanXinVersion version22_ = HanXinVersion._internal("Version22");

  ///
  static HanXinVersion version23_ = HanXinVersion._internal("Version23");

  ///
  static HanXinVersion version24_ = HanXinVersion._internal("Version24");

  ///
  static HanXinVersion version25_ = HanXinVersion._internal("Version25");

  ///
  static HanXinVersion version26_ = HanXinVersion._internal("Version26");

  ///
  static HanXinVersion version27_ = HanXinVersion._internal("Version27");

  ///
  static HanXinVersion version28_ = HanXinVersion._internal("Version28");

  ///
  static HanXinVersion version29_ = HanXinVersion._internal("Version29");

  ///
  static HanXinVersion version30_ = HanXinVersion._internal("Version30");

  ///
  static HanXinVersion version31_ = HanXinVersion._internal("Version31");

  ///
  static HanXinVersion version32_ = HanXinVersion._internal("Version32");

  ///
  static HanXinVersion version33_ = HanXinVersion._internal("Version33");

  ///
  static HanXinVersion version34_ = HanXinVersion._internal("Version34");

  ///
  static HanXinVersion version35_ = HanXinVersion._internal("Version35");

  ///
  static HanXinVersion version36_ = HanXinVersion._internal("Version36");

  ///
  static HanXinVersion version37_ = HanXinVersion._internal("Version37");

  ///
  static HanXinVersion version38_ = HanXinVersion._internal("Version38");

  ///
  static HanXinVersion version39_ = HanXinVersion._internal("Version39");

  ///
  static HanXinVersion version40_ = HanXinVersion._internal("Version40");

  ///
  static HanXinVersion version41_ = HanXinVersion._internal("Version41");

  ///
  static HanXinVersion version42_ = HanXinVersion._internal("Version42");

  ///
  static HanXinVersion version43_ = HanXinVersion._internal("Version43");

  ///
  static HanXinVersion version44_ = HanXinVersion._internal("Version44");

  ///
  static HanXinVersion version45_ = HanXinVersion._internal("Version45");

  ///
  static HanXinVersion version46_ = HanXinVersion._internal("Version46");

  ///
  static HanXinVersion version47_ = HanXinVersion._internal("Version47");

  ///
  static HanXinVersion version48_ = HanXinVersion._internal("Version48");

  ///
  static HanXinVersion version49_ = HanXinVersion._internal("Version49");

  ///
  static HanXinVersion version50_ = HanXinVersion._internal("Version50");

  ///
  static HanXinVersion version51_ = HanXinVersion._internal("Version51");

  ///
  static HanXinVersion version52_ = HanXinVersion._internal("Version52");

  ///
  static HanXinVersion version53_ = HanXinVersion._internal("Version53");

  ///
  static HanXinVersion version54_ = HanXinVersion._internal("Version54");

  ///
  static HanXinVersion version55_ = HanXinVersion._internal("Version55");

  ///
  static HanXinVersion version56_ = HanXinVersion._internal("Version56");

  ///
  static HanXinVersion version57_ = HanXinVersion._internal("Version57");

  ///
  static HanXinVersion version58_ = HanXinVersion._internal("Version58");

  ///
  static HanXinVersion version59_ = HanXinVersion._internal("Version59");

  ///
  static HanXinVersion version60_ = HanXinVersion._internal("Version60");

  ///
  static HanXinVersion version61_ = HanXinVersion._internal("Version61");

  ///
  static HanXinVersion version62_ = HanXinVersion._internal("Version62");

  ///
  static HanXinVersion version63_ = HanXinVersion._internal("Version63");

  ///
  static HanXinVersion version64_ = HanXinVersion._internal("Version64");

  ///
  static HanXinVersion version65_ = HanXinVersion._internal("Version65");

  ///
  static HanXinVersion version66_ = HanXinVersion._internal("Version66");

  ///
  static HanXinVersion version67_ = HanXinVersion._internal("Version67");

  ///
  static HanXinVersion version68_ = HanXinVersion._internal("Version68");

  ///
  static HanXinVersion version69_ = HanXinVersion._internal("Version69");

  ///
  static HanXinVersion version70_ = HanXinVersion._internal("Version70");

  ///
  static HanXinVersion version71_ = HanXinVersion._internal("Version71");

  ///
  static HanXinVersion version72_ = HanXinVersion._internal("Version72");

  ///
  static HanXinVersion version73_ = HanXinVersion._internal("Version73");

  ///
  static HanXinVersion version74_ = HanXinVersion._internal("Version74");

  ///
  static HanXinVersion version75_ = HanXinVersion._internal("Version75");

  ///
  static HanXinVersion version76_ = HanXinVersion._internal("Version76");

  ///
  static HanXinVersion version77_ = HanXinVersion._internal("Version77");

  ///
  static HanXinVersion version78_ = HanXinVersion._internal("Version78");

  ///
  static HanXinVersion version79_ = HanXinVersion._internal("Version79");

  ///
  static HanXinVersion version80_ = HanXinVersion._internal("Version80");

  ///
  static HanXinVersion version81_ = HanXinVersion._internal("Version81");

  ///
  static HanXinVersion version82_ = HanXinVersion._internal("Version82");

  ///
  static HanXinVersion version83_ = HanXinVersion._internal("Version83");

  ///
  static HanXinVersion version84_ = HanXinVersion._internal("Version84");

  HanXinVersion.fromJson(dynamic data) {
    switch (data) {
      case "Auto":
        value = data;
        break;
      case "Version01":
        value = data;
        break;
      case "Version02":
        value = data;
        break;
      case "Version03":
        value = data;
        break;
      case "Version04":
        value = data;
        break;
      case "Version05":
        value = data;
        break;
      case "Version06":
        value = data;
        break;
      case "Version07":
        value = data;
        break;
      case "Version08":
        value = data;
        break;
      case "Version09":
        value = data;
        break;
      case "Version10":
        value = data;
        break;
      case "Version11":
        value = data;
        break;
      case "Version12":
        value = data;
        break;
      case "Version13":
        value = data;
        break;
      case "Version14":
        value = data;
        break;
      case "Version15":
        value = data;
        break;
      case "Version16":
        value = data;
        break;
      case "Version17":
        value = data;
        break;
      case "Version18":
        value = data;
        break;
      case "Version19":
        value = data;
        break;
      case "Version20":
        value = data;
        break;
      case "Version21":
        value = data;
        break;
      case "Version22":
        value = data;
        break;
      case "Version23":
        value = data;
        break;
      case "Version24":
        value = data;
        break;
      case "Version25":
        value = data;
        break;
      case "Version26":
        value = data;
        break;
      case "Version27":
        value = data;
        break;
      case "Version28":
        value = data;
        break;
      case "Version29":
        value = data;
        break;
      case "Version30":
        value = data;
        break;
      case "Version31":
        value = data;
        break;
      case "Version32":
        value = data;
        break;
      case "Version33":
        value = data;
        break;
      case "Version34":
        value = data;
        break;
      case "Version35":
        value = data;
        break;
      case "Version36":
        value = data;
        break;
      case "Version37":
        value = data;
        break;
      case "Version38":
        value = data;
        break;
      case "Version39":
        value = data;
        break;
      case "Version40":
        value = data;
        break;
      case "Version41":
        value = data;
        break;
      case "Version42":
        value = data;
        break;
      case "Version43":
        value = data;
        break;
      case "Version44":
        value = data;
        break;
      case "Version45":
        value = data;
        break;
      case "Version46":
        value = data;
        break;
      case "Version47":
        value = data;
        break;
      case "Version48":
        value = data;
        break;
      case "Version49":
        value = data;
        break;
      case "Version50":
        value = data;
        break;
      case "Version51":
        value = data;
        break;
      case "Version52":
        value = data;
        break;
      case "Version53":
        value = data;
        break;
      case "Version54":
        value = data;
        break;
      case "Version55":
        value = data;
        break;
      case "Version56":
        value = data;
        break;
      case "Version57":
        value = data;
        break;
      case "Version58":
        value = data;
        break;
      case "Version59":
        value = data;
        break;
      case "Version60":
        value = data;
        break;
      case "Version61":
        value = data;
        break;
      case "Version62":
        value = data;
        break;
      case "Version63":
        value = data;
        break;
      case "Version64":
        value = data;
        break;
      case "Version65":
        value = data;
        break;
      case "Version66":
        value = data;
        break;
      case "Version67":
        value = data;
        break;
      case "Version68":
        value = data;
        break;
      case "Version69":
        value = data;
        break;
      case "Version70":
        value = data;
        break;
      case "Version71":
        value = data;
        break;
      case "Version72":
        value = data;
        break;
      case "Version73":
        value = data;
        break;
      case "Version74":
        value = data;
        break;
      case "Version75":
        value = data;
        break;
      case "Version76":
        value = data;
        break;
      case "Version77":
        value = data;
        break;
      case "Version78":
        value = data;
        break;
      case "Version79":
        value = data;
        break;
      case "Version80":
        value = data;
        break;
      case "Version81":
        value = data;
        break;
      case "Version82":
        value = data;
        break;
      case "Version83":
        value = data;
        break;
      case "Version84":
        value = data;
        break;
      default:
        throw Exception('Unknown enum value to decode: $data');
    }
  }

  static dynamic encode(HanXinVersion data) {
    return data.value;
  }

  String? toJson() {
    return value;
  }

  String toString() {
    return value == null ? "null" : value.toString();
  }
}
